import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

/** 列表筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
  {
    field: 'flag',
    label: ' ',
    component: 'Select',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '模块筛选',
      options: [
        { label: 'SQL文件', value: 'SQL文件' },
        { label: '数据加载', value: '数据加载' },
        { label: '数据同步', value: '数据同步' },
        { label: '自定义函数', value: '自定义函数' },
      ],
    },
  },
];

/** 列表展示字段*/
export const columns: BasicColumn[] = [
  {
    title: '规范名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '描述',
    dataIndex: 'des',
    width: 120,
  },
  {
    title: '所属模块',
    dataIndex: 'module',
    width: 120,
  },

];

/** 新增编辑表单字段*/
export const formSchema: any[] = [
  {
    field: 'name',
    label: '规范名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入规范名称',
      },
    ],
  },
  {
    field: 'regular',
    component: 'InputTextArea',
    label: '正则表达式',
    componentProps: {
      placeholder: '请输入正则表达式',
      rows: 4,
    },
    rules: [
      {
        required: true,
        message: '请输入正则表达式',
      },
    ],
  },
  {
    field: 'des',
    component: 'InputTextArea',
    label: '描述',
    componentProps: {
      placeholder: '请输入描述',
      rows: 4,
    },
  },
  {
    field: 'module',
    label: '所属模块',
    component: 'Select',
    componentProps: {
      mode: 'multiple',
      options: [
        { label: 'SQL文件', value: 'SQL文件' },
        { label: '数据加载', value: '数据加载' },
        { label: '数据同步', value: '数据同步' },
        { label: '自定义函数', value: '自定义函数' },
      ],
    },
  },
]
